@@ -1,13 +1,13 @@
 package Dist::Zooky;
 {
-  $Dist::Zooky::VERSION = '0.10';
+  $Dist::Zooky::VERSION = '0.12';
 }
 
 # ABSTRACT: converts a distribution to Dist::Zilla
 
 use strict;
 use warnings;
-use Class::MOP;
+use Class::Load ();
 use Moose;
 use MooseX::Types::Perl qw(DistName LaxVersionStr);
 use Dist::Zooky::License;
@@ -49,7 +49,7 @@ sub examine {
 
   foreach my $plugin ( $self->plugins ) {
     if ( $plugin =~ /$type$/ ) {
-      Class::MOP::load_class( $plugin );
+      Class::Load::load_class( $plugin );
       #$core = $plugin->new( ( $type eq 'MakeMaker' and $self->make ? ( make => $self->make ) : () ) );
       $core = $plugin->new( ( defined $self->make ? ( make => $self->make ) : () ) );
     }
@@ -89,17 +89,19 @@ no Moose;
 
 qq[And Dist::Zooky too!];
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zooky - converts a distribution to Dist::Zilla
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -136,10 +138,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chris Williams.
+This software is copyright (c) 2013 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
