@@ -1,6 +1,6 @@
 package Dist::Zooky::License;
 {
-  $Dist::Zooky::License::VERSION = '0.10';
+  $Dist::Zooky::License::VERSION = '0.12';
 }
 
 # ABSTRACT: license objects for Dist::Zooky
@@ -8,7 +8,7 @@ package Dist::Zooky::License;
 use strict;
 use warnings;
 use Module::Pluggable search_path => 'Software::License', except => qr/(Custom)$/;
-use Class::MOP;
+use Class::Load ();
 use Moose;
 
 has 'metaname' => (
@@ -29,7 +29,7 @@ sub _build_license {
   my $self = shift;
   my @licenses;
   foreach my $plugin ( $self->plugins ) {
-    Class::MOP::load_class( $plugin );
+    Class::Load::load_class( $plugin );
     my $license = $plugin->new({ holder => 'noddy' }); # need to set holder
     push @licenses, $license
       if $license->meta2_name eq $self->metaname
@@ -43,17 +43,19 @@ no Moose;
 
 qq[Licenses];
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zooky::License - license objects for Dist::Zooky
 
 =head1 VERSION
 
-version 0.10
+version 0.12
 
 =head1 AUTHOR
 
@@ -61,10 +63,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Chris Williams.
+This software is copyright (c) 2013 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
